@@ -1,4 +1,4 @@
-// $Id: performance.java,v 1.7 1998/08/07 13:20:19 oliva Exp $
+// $Id: performance.java,v 1.8 1998/09/23 06:30:18 oliva Exp $
 
 /* Copyright 1998 Alexandre Oliva <oliva@dcc.unicamp.br>
  *
@@ -24,7 +24,7 @@ import java.util.Vector;
  * This program times several Java operations.
  *
  * @author Alexandre Oliva
- * @version $Revision: 1.7 $
+ * @version $Revision: 1.8 $
  */
 public class performance {
     static finaltest object = statictest.createFinal();
@@ -247,10 +247,10 @@ public class performance {
 	}, new test() {
 	    public String toString() { return "println"; }
 	    public long run(int count) {
-		System.err.println("Hello world!");
+		System.out.println("Hello world!");
 		long start = System.currentTimeMillis();
 		while(count-- > 0) {
-		    System.err.println("Hello world!");
+		    System.out.println("Hello world!");
 		}
 		return System.currentTimeMillis() - start;
 	    }
@@ -308,10 +308,10 @@ public class performance {
     static boolean stat = true;
     static void runtestAndPrint(test t) {
 	if (stat)
-	    System.out.print(t + ": ");
+	    System.err.print(t + ": ");
 	double avgtime = runtest(t, null);
 	if (stat)
-	    System.out.println(avgtime);
+	    System.err.println(avgtime);
     }
     static double runtest(test t, Vector sizelist) {
 	int count = 1;
